@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.3.1)
- * Copyright (C) 2023 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -20,12 +20,10 @@
  */
 package jalview.api;
 
-import jalview.datamodel.SequenceGroup;
 import jalview.datamodel.SequenceI;
 import jalview.renderer.seqfeatures.FeatureColourFinder;
 
 import java.awt.Color;
-import java.awt.Graphics;
 
 public interface SequenceRenderer
 {
@@ -33,22 +31,4 @@ public interface SequenceRenderer
   Color getResidueColour(SequenceI seq, int position,
           FeatureColourFinder finder);
 
-  /**
-   * Configure the Graphics canvas and render options for the renderer
-   * 
-   * @param g
-   *          - the canvas to render to
-   * @param renderGaps
-   *          - when true, gap characters will be included when rendered
-   * 
-   */
-  void prepare(Graphics g, boolean renderGaps);
-
-  void drawSequence(SequenceI nextSeq, SequenceGroup[] findAllGroups,
-          int startRes, int endRes, int i);
-
-  void drawHighlightedText(SequenceI nextSeq, int i, int j, int k, int l);
-
-  void drawCursor(Graphics g, char s, int i, int j);
-
 }
