@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.1.4)
- * Copyright (C) 2021 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -20,6 +20,8 @@
  */
 package jalview.bin;
 
+import java.util.Locale;
+
 import jalview.analysis.AlignmentUtils;
 import jalview.api.StructureSelectionManagerProvider;
 import jalview.appletgui.AlignFrame;
@@ -207,8 +209,9 @@ public class JalviewLite extends Applet
       final StructureSelectionManagerProvider me = this;
       final int pos = apos;
       // use vamsas listener to broadcast to all listeners in scope
-      if (alignedPosition != null && (alignedPosition.trim().length() == 0
-              || alignedPosition.toLowerCase().indexOf("false") > -1))
+      if (alignedPosition != null
+              && (alignedPosition.trim().length() == 0 || alignedPosition
+                      .toLowerCase(Locale.ROOT).indexOf("false") > -1))
       {
         java.awt.EventQueue.invokeLater(new Runnable()
         {
@@ -412,7 +415,7 @@ public class JalviewLite extends Applet
             r--;
           } catch (NumberFormatException ex)
           {
-            if (cl.toLowerCase().equals("sequence"))
+            if (cl.toLowerCase(Locale.ROOT).equals("sequence"))
             {
               // we are in the dataset sequence's coordinate frame.
               inseqpos = true;
@@ -1333,7 +1336,7 @@ public class JalviewLite extends Applet
   private boolean alignPdbStructures = false;
 
   /**
-   * use an external structure viewer exclusively (no jmols or MCViews will be
+   * use an external structure viewer exclusively (no jmols or mc_views will be
    * opened by JalviewLite itself)
    */
   public boolean useXtrnalSviewer = false;
@@ -1440,7 +1443,8 @@ public class JalviewLite extends Applet
     String externalsviewer = getParameter("externalstructureviewer");
     if (externalsviewer != null)
     {
-      useXtrnalSviewer = externalsviewer.trim().toLowerCase().equals(TRUE);
+      useXtrnalSviewer = externalsviewer.trim().toLowerCase(Locale.ROOT)
+              .equals(TRUE);
     }
     /**
      * if true disable the check for jmol
@@ -1798,7 +1802,7 @@ public class JalviewLite extends Applet
           if (!jmolAvailable)
           {
             System.out.println(
-                    "Jmol not available - Using MCview for structures");
+                    "Jmol not available - Using mc_view for structures");
           }
         } catch (java.lang.ClassNotFoundException ex)
         {
@@ -1810,7 +1814,7 @@ public class JalviewLite extends Applet
         if (debug)
         {
           System.err.println(
-                  "Skipping Jmol check. Will use MCView (probably)");
+                  "Skipping Jmol check. Will use mc_view (probably)");
         }
       }
       checkedForJmol = true;
@@ -2691,7 +2695,7 @@ public class JalviewLite extends Applet
           final String groups, boolean state)
   {
     final boolean st = state;// !(state==null || state.equals("") ||
-    // state.toLowerCase().equals("false"));
+    // state.toLowerCase(Locale.ROOT).equals("false"));
     java.awt.EventQueue.invokeLater(new Runnable()
     {
       @Override
