@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
- * Copyright (C) 2022 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.5.0)
+ * Copyright (C) 2025 The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -401,8 +401,8 @@ public class FeatureStore
       SequenceFeature sf = contactFeatureEnds.get(index);
       if (!sf.isContactFeature())
       {
-        System.err.println("Error! non-contact feature type " + sf.getType()
-                + " in contact features list");
+        jalview.bin.Console.errPrintln("Error! non-contact feature type "
+                + sf.getType() + " in contact features list");
         index++;
         continue;
       }
@@ -454,8 +454,8 @@ public class FeatureStore
       SequenceFeature sf = contactFeatureStarts.get(index);
       if (!sf.isContactFeature())
       {
-        System.err.println("Error! non-contact feature " + sf.toString()
-                + " in contact features list");
+        jalview.bin.Console.errPrintln("Error! non-contact feature "
+                + sf.toString() + " in contact features list");
         index++;
         continue;
       }
