@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.1)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -137,9 +137,8 @@ public class PfamFile extends AlignFile
       }
       else
       {
-        jalview.bin.Console
-                .errPrintln("PFAM File reader: Can't find sequence for "
-                        + headers.get(i));
+        System.err.println("PFAM File reader: Can't find sequence for "
+                + headers.get(i));
       }
     }
   }
