@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.1.4)
- * Copyright (C) 2021 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.5.0)
+ * Copyright (C) 2025 The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -20,9 +20,12 @@
  */
 package jalview.ws.jws1;
 
+import java.util.Hashtable;
+
 import jalview.analysis.AlignSeq;
+import jalview.analysis.AlignmentAnnotationUtils;
 import jalview.analysis.SeqsetUtils;
-import jalview.bin.Cache;
+import jalview.bin.Console;
 import jalview.datamodel.Alignment;
 import jalview.datamodel.AlignmentAnnotation;
 import jalview.datamodel.AlignmentI;
@@ -44,10 +47,6 @@ import jalview.util.MessageManager;
 import jalview.ws.AWsJob;
 import jalview.ws.JobStateSummary;
 import jalview.ws.WSClientI;
-
-import java.util.Hashtable;
-import java.util.List;
-
 import vamsas.objects.simple.JpredResult;
 
 class JPredThread extends JWS1Thread implements WSClientI
@@ -119,17 +118,17 @@ class JPredThread extends JWS1Thread implements WSClientI
 
       JpredResult result = (JpredResult) this.result;
 
-      Cache.log.debug("Parsing output from JNet job.");
+      Console.debug("Parsing output from JNet job.");
       // JPredFile prediction = new JPredFile("C:/JalviewX/files/jpred.txt",
       // "File");
       JPredFile prediction = new JPredFile(result.getPredfile(),
               DataSourceType.PASTE);
       SequenceI[] preds = prediction.getSeqsAsArray();
-      Cache.log.debug("Got prediction profile.");
+      Console.debug("Got prediction profile.");
 
       if ((this.msa != null) && (result.getAligfile() != null))
       {
-        Cache.log.debug("Getting associated alignment.");
+        Console.debug("Getting associated alignment.");
         // we ignore the returned alignment if we only predicted on a single
         // sequence
         FileFormatI format = new IdentifyFile()
@@ -244,7 +243,7 @@ class JPredThread extends JWS1Thread implements WSClientI
       {
         if (alant.sequenceRef != null)
         {
-          replaceAnnotationOnAlignmentWith(alant, alant.label,
+          AlignmentAnnotationUtils.replaceAnnotationOnAlignmentWith(alant, alant.label,
                   "jalview.jws1.Jpred" + (this.msa == null ? "" : "MSA"),
                   alant.sequenceRef);
         }
@@ -252,38 +251,6 @@ class JPredThread extends JWS1Thread implements WSClientI
       return new Object[] { al, alhidden }; // , FirstSeq, noMsa};
     }
 
-    /**
-     * copied from JabawsCalcWorker
-     * 
-     * @param newAnnot
-     * @param typeName
-     * @param calcId
-     * @param aSeq
-     */
-    protected void replaceAnnotationOnAlignmentWith(
-            AlignmentAnnotation newAnnot, String typeName, String calcId,
-            SequenceI aSeq)
-    {
-      SequenceI dsseq = aSeq.getDatasetSequence();
-      while (dsseq.getDatasetSequence() != null)
-      {
-        dsseq = dsseq.getDatasetSequence();
-      }
-      // look for same annotation on dataset and lift this one over
-      List<AlignmentAnnotation> dsan = dsseq.getAlignmentAnnotations(calcId,
-              typeName);
-      if (dsan != null && dsan.size() > 0)
-      {
-        for (AlignmentAnnotation dssan : dsan)
-        {
-          dsseq.removeAlignmentAnnotation(dssan);
-        }
-      }
-      AlignmentAnnotation dssan = new AlignmentAnnotation(newAnnot);
-      dsseq.addAlignmentAnnotation(dssan);
-      dssan.adjustForAlignment();
-    }
-
     /**
      * Given an alignment where all other sequences except profileseq are
      * aligned to the ungapped profileseq, insert gaps in the other sequences to
@@ -461,7 +428,7 @@ class JPredThread extends JWS1Thread implements WSClientI
         {
           job.setSubmitted(true);
           job.setSubjobComplete(false);
-          Cache.log.info(WsUrl + " Job Id '" + job.getJobId() + "'");
+          Console.info(WsUrl + " Job Id '" + job.getJobId() + "'");
         }
       }
       else
@@ -480,11 +447,11 @@ class JPredThread extends JWS1Thread implements WSClientI
         wsInfo.setProgressText(j.getJobnum(),
                 "Failed to submit the prediction. (Just close the window)\n"
                         + "It is most likely that there is a problem with the server.\n");
-        System.err.println(
+        jalview.bin.Console.errPrintln(
                 "JPredWS Client: Failed to submit the prediction. Quite possibly because of a server error - see below)\n"
                         + e.getMessage() + "\n");
 
-        jalview.bin.Cache.log.warn("Server Exception", e);
+        Console.warn("Server Exception", e);
       }
       else
       {
@@ -495,8 +462,7 @@ class JPredThread extends JWS1Thread implements WSClientI
                         "info.failed_to_submit_prediction", new String[]
                         { e.getMessage(), wsInfo.getProgressText() }));
 
-        jalview.bin.Cache.log
-                .debug("Failed Submission of job " + j.getJobnum(), e);
+        Console.debug("Failed Submission of job " + j.getJobnum(), e);
 
       }
       j.setAllowedServerExceptions(-1);
@@ -523,7 +489,7 @@ class JPredThread extends JWS1Thread implements WSClientI
     } catch (Exception ex)
     {
 
-      Cache.log.error(
+      Console.error(
               "Unexpected exception when processing results for " + altitle,
               ex);
       wsInfo.setStatus(WebserviceInfo.STATE_STOPPED_ERROR);
@@ -577,9 +543,9 @@ class JPredThread extends JWS1Thread implements WSClientI
           msa = (j.msa != null) ? true : msa;
           try
           {
-            jalview.bin.Cache.log.debug("Parsing output of job " + jn);
+            Console.debug("Parsing output of job " + jn);
             jobres = j.getResultSet();
-            jalview.bin.Cache.log.debug("Finished parsing output.");
+            Console.debug("Finished parsing output.");
             if (jobs.length == 1)
             {
               res = jobres;
@@ -592,8 +558,7 @@ class JPredThread extends JWS1Thread implements WSClientI
             }
           } catch (Exception e)
           {
-            jalview.bin.Cache.log
-                    .error("JNet Client: JPred Annotation Parse Error", e);
+            Console.error("JNet Client: JPred Annotation Parse Error", e);
             wsInfo.setStatus(j.getJobnum(),
                     WebserviceInfo.STATE_STOPPED_ERROR);
             wsInfo.appendProgressText(j.getJobnum(),
@@ -652,7 +617,7 @@ class JPredThread extends JWS1Thread implements WSClientI
         }
         else
         {
-          Cache.log.info("Append results onto existing alignment.");
+          Console.info("Append results onto existing alignment.");
         }
       }
     }
